@@ -1,7 +1,8 @@
 __all__ = ['Server']
 
 
-from .core import Server
+from .base.core import Server
 
 
+__doc__ = Server.__doc__
 __version__ = Server.__version__
